==> servicetalk-http-api-0.22.0-sources.jar: io/servicetalk/http/api/ReservedBlockingHttpConnection.java <==
/*
 * Copyright © 2019 Apple Inc. and the ServiceTalk project authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.servicetalk.http.api;

/**
 * A special type of {@link BlockingHttpConnection} for the exclusive use of the caller of
 * {@link BlockingHttpClient#reserveConnection(HttpRequestMetaData)} and
 * {@link BlockingHttpClient#reserveConnection(HttpExecutionStrategy, HttpRequestMetaData)}.
 */
public interface ReservedBlockingHttpConnection extends BlockingHttpConnection {
    /**
     * Releases this reserved {@link BlockingHttpConnection} to be used for subsequent requests.
     * This method must be idempotent, i.e. calling multiple times must not have side-effects.
     *
     * @throws Exception if any exception occurs during releasing.
     */
    void release() throws Exception;

    @Override
    ReservedStreamingHttpConnection asStreamingConnection();

    @Override
    default ReservedHttpConnection asConnection() {
        return asStreamingConnection().asConnection();
    }

    @Override
    default ReservedBlockingStreamingHttpConnection asBlockingStreamingConnection() {
        return asStreamingConnection().asBlockingStreamingConnection();
    }
}

==> servicetalk-http-api-0.42.31-sources.jar: io/servicetalk/http/api/ReservedBlockingHttpConnection.java <==
/*
 * Copyright © 2019 Apple Inc. and the ServiceTalk project authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.servicetalk.http.api;

/**
 * A special type of {@link BlockingHttpConnection} for the exclusive use of the caller of
 * {@link BlockingHttpClient#reserveConnection(HttpRequestMetaData)}.
 */
public interface ReservedBlockingHttpConnection extends BlockingHttpConnection {
    /**
     * Releases this reserved {@link BlockingHttpConnection} to be used for subsequent requests.
     * This method must be idempotent, i.e. calling multiple times must not have side-effects.
     *
     * @throws Exception if any exception occurs during releasing.
     */
    void release() throws Exception;

    @Override
    ReservedStreamingHttpConnection asStreamingConnection();

    @Override
    default ReservedHttpConnection asConnection() {
        return asStreamingConnection().asConnection();
    }

    @Override
    default ReservedBlockingStreamingHttpConnection asBlockingStreamingConnection() {
        return asStreamingConnection().asBlockingStreamingConnection();
    }
}
